@@ -162,7 +162,6 @@ class Router:
             methods = set (options.get ("methods", []))
             if not methods:
                 methods = {"GET", "POST"}
-
         resource ["__proto__"] = proto
         resource ["__default__"] = proto
         for method in options.get ("methods", methods):
@@ -172,6 +171,14 @@ class Router:
         for proto in resource.values ():
             proto [-1]["methods"] = methods
 
+    def optimal_proto (self, map, key, func_id):
+        method = '__proto__'
+        for method_ in map [key]:
+            if func_id == map [key][method_][6]['func_id']:
+                method = method_
+                break
+        return map [key][method]
+
     # URL Building ------------------------------------------------
     def urlfor (self, thing, *args, **kargs):
         if isinstance (thing, FunctionType):
@@ -184,12 +191,14 @@ class Router:
             fpath = self._function_names [thing]
             if len (fpath) == 2:
                 if not args and not kargs:
-                    proto = self.route_map [fpath [0]]['__proto__']
+                    proto = self.optimal_proto (self.route_map, fpath [0], thing)
                 else:
-                    proto = self.route_map_fancy [fpath [0]][fpath [1]]['__proto__']
+                    proto = self.optimal_proto (self.route_map_fancy [fpath [0]], fpath [1], thing)
             else:
-                proto = self.route_map [fpath [0]]['__proto__']
+                proto = self.optimal_proto (self.route_map, fpath [0], thing)
+
         except KeyError:
+            raise
             raise NameError ("{} not found".format (str (thing)))
 
         func, name, fuvars, favars, numvars, str_rule, options = proto
@@ -298,11 +307,13 @@ class Router:
         if not path_info:
             return self.urlfor ("/"), None
         if path_info in self.route_map:
-            #command = command in self.route_map [path_info] and command or "__default__"
             try:
                 proto = self.route_map [path_info][command]
             except KeyError:
-                raise AssertionError
+                if command == 'OPTIONS' and self.access_control_allow_origin:
+                    proto = self.route_map [path_info]['__proto__']
+                else:
+                    raise AssertionError
             return proto [0], proto [-1]
 
         trydir = path_info + "/"
