@@ -44,23 +44,23 @@ class BasicMethods:
 		return self.remove (k)
 
 	def __contains__ (self, k):
-		self.data is None and self.__parse ()
+		self.data is None and self._parse ()
 		return k in self.data
 
 	def has_key (self, k):
-		self.data is None and self.__parse ()
+		self.data is None and self._parse ()
 		return k in self.data
 
 	def items (self):
-		self.data is None and self.__parse ()
+		self.data is None and self._parse ()
 		return self.data.items ()
 
 	def keys (self):
-		self.data is None and self.__parse ()
+		self.data is None and self._parse ()
 		return self.data.keys ()
 
 	def values (self):
-		self.data is None and self.__parse ()
+		self.data is None and self._parse ()
 		return self.data.values ()
 
 
@@ -80,7 +80,7 @@ class Cookie (BasicMethods):
 		self.uncommits = {}
 		self.sessions = {}
 
-	def __parse (self):
+	def _parse (self):
 		self.data = {}
 		cookie = crack_cookie (self.request.get_header ("cookie"))
 		for k, v in list(cookie.items ()):
@@ -90,11 +90,11 @@ class Cookie (BasicMethods):
 			self.data [k] = v
 
 	def get (self, k, a = None):
-		self.data is None and self.__parse ()
+		self.data is None and self._parse ()
 		return self.data.get (k, a)
 
 	def remove (self, k, path = None, domain = None):
-		self.data is None and self.__parse ()
+		self.data is None and self._parse ()
 		try:
 			del self.data [k]
 		except KeyError:
@@ -103,7 +103,7 @@ class Cookie (BasicMethods):
 			self.set (k, "", 0, path, domain)
 
 	def clear (self, path = None, domain = None):
-		self.data is None and self.__parse ()
+		self.data is None and self._parse ()
 		for k, v in list(self.data.items ()):
 			self.set (k, "", 0, path, domain)
 		self.data = {}
@@ -119,7 +119,7 @@ class Cookie (BasicMethods):
 		self.dirty = False
 
 	def set (self, name, val = "", expires = None, path = None, domain = None, secure = False, http_only = False):
-		self.data is None and self.__parse ()
+		self.data is None and self._parse ()
 
 		self.dirty = True
 		if path is None:
@@ -175,7 +175,7 @@ class Cookie (BasicMethods):
 				self.data [name] = val
 
 	def get_named_session_data (self, name):
-		self.data is None and self.__parse ()
+		self.data is None and self._parse ()
 		return self.sessions.get (name)
 
 	def get_session (self):
