@@ -69,7 +69,7 @@ class WAS (wsgiappservice.WAS):
         return signature == signature_
 
     def make_uid (self, s):
-        return base64.encodestring (md5 (s.encode ()).digest ()) [:-3].decode ().replace ('/', '-').replace ('+', '_')
+        return base64.encodestring (md5 (s.encode ()).digest ()) [:-3].decode ().replace ('/', '-').replace ('+', '.')
 
     # JWT token --------------------------------------------------
     def mkjwt (self, claim, salt = None, alg = "HS256"):
@@ -168,26 +168,31 @@ class WAS (wsgiappservice.WAS):
     detoken = deott
 
     # CSRF token ------------------------------------------------------
-    CSRF_NAME = "_csrf_token"
+    CSRF_NAME = "XSRF_TOKEN" #axios compat
     @property
     def csrf_token (self):
-        self.session.mount ()
-        if self.CSRF_NAME not in self.session:
-            self.session [self.CSRF_NAME] = hex (random.getrandbits (64)) [2:]
-        return self.session [self.CSRF_NAME]
+        if self.CSRF_NAME not in self.cookie:
+            tok = hex (random.getrandbits (64)) [2:]
+            self.cookie [self.CSRF_NAME] = tok
+        return self.cookie [self.CSRF_NAME]
 
     @property
     def csrf_token_input (self):
         return '<input type="hidden" name="{}" value="{}">'.format (self.CSRF_NAME, self.csrf_token)
 
+    def remove_csrf (self):
+        try:
+            del self.cookie [self.CSRF_NAME]
+        except KeyError:
+            pass
+
     def verify_csrf (self, keep = True):
-        token = self.request.get_header ('x-csrf-token', self.request.args.get (self.CSRF_NAME))
+        token = self.request.get_header ('X-{}'.format (self.CSRF_NAME.replace ("_", "-")), self.request.args.get (self.CSRF_NAME))
         if not token:
             return False
         if self.csrf_token == token:
             if not keep:
-                self.session.mount ()
-                del self.session [self.CSRF_NAME]
+                del self.cookie [self.CSRF_NAME]
             return True
         return False
     csrf_verify = verify_csrf
