@@ -278,6 +278,9 @@ class Executor:
 
 		except MemoryError:
 			raise
+		except AssertionError as e:
+			self.rollback ()
+			content = [request.response.with_explain ('400 Not My Fault', *e.args [:1])]
 		except HTTPError as e:
 			self.rollback ()
 			content = [request.response.with_explain (e.status, e.explain, e.errno)]
